# Class: SR

A storage repository

## Fields for class: SR

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`storage_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`blobs`             |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this SR    |
|`clustered`         |`bool`              |_RO/runtime_   |True if the SR is using aggregated local storage|
|`content_type`      |`string`            |_RO/constructor_|the type of the SR's content, if required &#40;e.g. ISOs&#41;|
|`current_operations`|`(string -> storage_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`introduced_by`     |`DR_task ref`       |_RO/runtime_   |The disaster recovery task which introduced this SR|
|`is_tools_sr`       |`bool`              |_RO/runtime_   |True if this is the SR that contains the Tools ISO VDIs|
|`local_cache_enabled`|`bool`              |_RO/runtime_   |True if this SR is assigned to be the local cache for its host|
|`name_description`  |`string`            |_RO/constructor_|a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RO/constructor_|a human&#45;readable name               |
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`PBDs`              |`PBD ref set`       |_RO/runtime_   |describes how particular hosts can see this storage repository|
|`physical_size`     |`int`               |_RO/constructor_|total physical size of the repository &#40;in bytes&#41;|
|`physical_utilisation`|`int`               |_RO/runtime_   |physical space currently utilised on this storage repository &#40;in bytes&#41;. Note that for sparse disk formats, physical&#95;utilisation may be less than virtual&#95;allocation|
|`shared`            |`bool`              |_RO/runtime_   |true if this SR is &#40;capable of being&#41; shared between multiple hosts|
|`sm_config`         |`(string -> string) map`|_RW_           |SM dependent data                       |
|`tags`              |`string set`        |_RW_           |user&#45;specified tags for categorization purposes|
|`type`              |`string`            |_RO/constructor_|type of the storage repository          |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VDIs`              |`VDI ref set`       |_RO/runtime_   |all virtual disks known to this storage repository|
|`virtual_allocation`|`int`               |_RO/runtime_   |sum of virtual&#95;sizes of all VDIs in this storage repository &#40;in bytes&#41;|

## RPCs associated with class: SR

### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given SR.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_ref, SR ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given SR.

_Signature:_

```
void add_to_other_config (session ref session_ref, SR ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: add&#95;to&#95;sm&#95;config

_Overview:_

Add the given key&#45;value pair to the sm&#95;config field of the given SR.

_Signature:_

```
void add_to_sm_config (session ref session_ref, SR ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: assert&#95;can&#95;host&#95;ha&#95;statefile

_Overview:_

Returns successfully if the given SR can host an HA statefile. Otherwise returns an error to explain why not

_Signature:_

```
void assert_can_host_ha_statefile (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR to query                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: assert&#95;supports&#95;database&#95;replication

_Overview:_

Returns successfully if the given SR supports database replication. Otherwise returns an error to explain why not.

_Signature:_

```
void assert_supports_database_replication (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR to query                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new Storage Repository and introduce it into the managed system, creating both SR record and PBD record to attach it to current host &#40;with specified device&#95;config parameters&#41;

_Signature:_

```
SR ref create (session ref session_ref, host ref host, (string -> string) map device_config, int physical_size, string name_label, string name_description, string type, string content_type, bool shared, (string -> string) map sm_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to create/make the SR on       |
|`(string -> string) map`      |`device_config`               |The device config string that will be passed to backend SR driver|
|`int`                         |`physical_size`               |The physical size of the new storage repository|
|`string`                      |`name_label`                  |The name of the new storage repository  |
|`string`                      |`name_description`            |The description of the new storage repository|
|`string`                      |`type`                        |The type of the SR; used to specify the SR backend driver to use|
|`string`                      |`content_type`                |The type of the new SRs content, if required &#40;e.g. ISOs&#41;|
|`bool`                        |`shared`                      |True if the SR &#40;is capable of&#41; being shared by multiple hosts|
|`(string -> string) map`      |`sm_config`                   |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `SR ref`

The reference of the newly created Storage Repository.

_Possible Error Codes:_ `SR_UNKNOWN_DRIVER`

### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this SR

_Signature:_

```
blob ref create_new_blob (session ref session_ref, SR ref sr, string name, string mime_type, bool public)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR                                  |
|`string`                      |`name`                        |The name associated with the blob       |
|`string`                      |`mime_type`                   |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool`                        |`public`                      |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

### RPC name: destroy

_Overview:_

Destroy specified SR, removing SR&#45;record from database and remove SR from disk. &#40;In order to affect this operation the appropriate device&#95;config is read from the specified SR's PBD on current host&#41;

_Signature:_

```
void destroy (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR to destroy                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `SR_HAS_PBD`

### RPC name: disable&#95;database&#95;replication

_Overview:_

_Signature:_

```
void disable_database_replication (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR to which metadata should be no longer replicated|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: enable&#95;database&#95;replication

_Overview:_

_Signature:_

```
void enable_database_replication (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR to which metadata should be replicated|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: forget

_Overview:_

Removing specified SR&#45;record from database, without attempting to remove SR from disk

_Signature:_

```
void forget (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR to destroy                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `SR_HAS_PBD`

### RPC name: forget&#95;data&#95;source&#95;archives

_Overview:_

Forget the recorded statistics related to the specified data source

_Signature:_

```
void forget_data_source_archives (session ref session_ref, SR ref sr, string data_source)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR                                  |
|`string`                      |`data_source`                 |The data source whose archives are to be forgotten|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the SRs known to the system.

_Signature:_

```
SR ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of SR references to SR records for all SRs known to the system.

_Signature:_

```
(SR ref -> SR record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(SR ref -> SR record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given SR.

_Signature:_

```
storage_operations set get_allowed_operations (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `storage_operations set`

value of the field

### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given SR.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the SR instances with the given label.

_Signature:_

```
SR ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the SR instance with the specified UUID.

_Signature:_

```
SR ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

reference to the object

### RPC name: get&#95;clustered

_Overview:_

Get the clustered field of the given SR.

_Signature:_

```
bool get_clustered (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;content&#95;type

_Overview:_

Get the content&#95;type field of the given SR.

_Signature:_

```
string get_content_type (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given SR.

_Signature:_

```
(string -> storage_operations) map get_current_operations (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> storage_operations) map`

value of the field

### RPC name: get&#95;data&#95;sources

_Overview:_

_Signature:_

```
data_source record set get_data_sources (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR to interrogate                   |

_Minimum Role:_ read-only

_Return Type:_ `data_source record set`

A set of data sources

### RPC name: get&#95;introduced&#95;by

_Overview:_

Get the introduced&#95;by field of the given SR.

_Signature:_

```
DR_task ref get_introduced_by (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `DR_task ref`

value of the field

### RPC name: get&#95;is&#95;tools&#95;sr

_Overview:_

Get the is&#95;tools&#95;sr field of the given SR.

_Signature:_

```
bool get_is_tools_sr (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;local&#95;cache&#95;enabled

_Overview:_

Get the local&#95;cache&#95;enabled field of the given SR.

_Signature:_

```
bool get_local_cache_enabled (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given SR.

_Signature:_

```
string get_name_description (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given SR.

_Signature:_

```
string get_name_label (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given SR.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PBDs

_Overview:_

Get the PBDs field of the given SR.

_Signature:_

```
PBD ref set get_PBDs (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PBD ref set`

value of the field

### RPC name: get&#95;physical&#95;size

_Overview:_

Get the physical&#95;size field of the given SR.

_Signature:_

```
int get_physical_size (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;physical&#95;utilisation

_Overview:_

Get the physical&#95;utilisation field of the given SR.

_Signature:_

```
int get_physical_utilisation (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given SR.

_Signature:_

```
SR record get_record (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR record`

all fields from the object

### RPC name: get&#95;shared

_Overview:_

Get the shared field of the given SR.

_Signature:_

```
bool get_shared (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;sm&#95;config

_Overview:_

Get the sm&#95;config field of the given SR.

_Signature:_

```
(string -> string) map get_sm_config (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;supported&#95;types

_Overview:_

Return a set of all the SR types supported by the system

_Signature:_

```
string set get_supported_types (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `string set`

the supported SR types

### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given SR.

_Signature:_

```
string set get_tags (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;type

_Overview:_

Get the type field of the given SR.

_Signature:_

```
string get_type (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given SR.

_Signature:_

```
string get_uuid (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VDIs

_Overview:_

Get the VDIs field of the given SR.

_Signature:_

```
VDI ref set get_VDIs (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

value of the field

### RPC name: get&#95;virtual&#95;allocation

_Overview:_

Get the virtual&#95;allocation field of the given SR.

_Signature:_

```
int get_virtual_allocation (session ref session_ref, SR ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: introduce

_Overview:_

Introduce a new Storage Repository into the managed system

_Signature:_

```
SR ref introduce (session ref session_ref, string uuid, string name_label, string name_description, string type, string content_type, bool shared, (string -> string) map sm_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |The uuid assigned to the introduced SR  |
|`string`                      |`name_label`                  |The name of the new storage repository  |
|`string`                      |`name_description`            |The description of the new storage repository|
|`string`                      |`type`                        |The type of the SR; used to specify the SR backend driver to use|
|`string`                      |`content_type`                |The type of the new SRs content, if required &#40;e.g. ISOs&#41;|
|`bool`                        |`shared`                      |True if the SR &#40;is capable of&#41; being shared by multiple hosts|
|`(string -> string) map`      |`sm_config`                   |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `SR ref`

The reference of the newly introduced Storage Repository.

### RPC name: make

**This message is deprecated.**

_Overview:_

Create a new Storage Repository on disk. This call is deprecated: use SR.create instead.

_Signature:_

```
string make (session ref session_ref, host ref host, (string -> string) map device_config, int physical_size, string name_label, string name_description, string type, string content_type, (string -> string) map sm_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to create/make the SR on       |
|`(string -> string) map`      |`device_config`               |The device config string that will be passed to backend SR driver|
|`int`                         |`physical_size`               |The physical size of the new storage repository|
|`string`                      |`name_label`                  |The name of the new storage repository  |
|`string`                      |`name_description`            |The description of the new storage repository|
|`string`                      |`type`                        |The type of the SR; used to specify the SR backend driver to use|
|`string`                      |`content_type`                |The type of the new SRs content, if required &#40;e.g. ISOs&#41;|
|`(string -> string) map`      |`sm_config`                   |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `string`

The uuid of the newly created Storage Repository.

### RPC name: probe

_Overview:_

Perform a backend&#45;specific scan, using the given device&#95;config.  If the device&#95;config is complete, then this will return a list of the SRs present of this type on the device, if any.  If the device&#95;config is partial, then a backend&#45;specific scan will be performed, returning results that will guide the user in improving the device&#95;config.

_Signature:_

```
string probe (session ref session_ref, host ref host, (string -> string) map device_config, string type, (string -> string) map sm_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to create/make the SR on       |
|`(string -> string) map`      |`device_config`               |The device config string that will be passed to backend SR driver|
|`string`                      |`type`                        |The type of the SR; used to specify the SR backend driver to use|
|`(string -> string) map`      |`sm_config`                   |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `string`

An XML fragment containing the scan results.  These are specific to the scan being performed, and the backend.

### RPC name: probe&#95;ext

_Overview:_

Perform a backend&#45;specific scan, using the given device&#95;config.  If the device&#95;config is complete, then this will return a list of the SRs present of this type on the device, if any.  If the device&#95;config is partial, then a backend&#45;specific scan will be performed, returning results that will guide the user in improving the device&#95;config.

_Signature:_

```
probe_result record set probe_ext (session ref session_ref, host ref host, (string -> string) map device_config, string type, (string -> string) map sm_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`host ref`                    |`host`                        |The host to create/make the SR on       |
|`(string -> string) map`      |`device_config`               |The device config string that will be passed to backend SR driver|
|`string`                      |`type`                        |The type of the SR; used to specify the SR backend driver to use|
|`(string -> string) map`      |`sm_config`                   |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `probe_result record set`

A set of records containing the scan results.

### RPC name: query&#95;data&#95;source

_Overview:_

Query the latest value of the specified data source

_Signature:_

```
float query_data_source (session ref session_ref, SR ref sr, string data_source)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR                                  |
|`string`                      |`data_source`                 |The data source to query                |

_Minimum Role:_ read-only

_Return Type:_ `float`

The latest value, averaged over the last 5 seconds

### RPC name: record&#95;data&#95;source

_Overview:_

Start recording the specified data source

_Signature:_

```
void record_data_source (session ref session_ref, SR ref sr, string data_source)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR                                  |
|`string`                      |`data_source`                 |The data source to record               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given SR.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, SR ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;from&#95;sm&#95;config

_Overview:_

Remove the given key and its corresponding value from the sm&#95;config field of the given SR.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_sm_config (session ref session_ref, SR ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given SR.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_ref, SR ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`string`                      |`value`                       |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: scan

_Overview:_

Refreshes the list of VDIs associated with an SR

_Signature:_

```
void scan (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR to scan                          |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name description of the SR

_Signature:_

```
void set_name_description (session ref session_ref, SR ref sr, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR                                  |
|`string`                      |`value`                       |The name description for the SR         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name label of the SR

_Signature:_

```
void set_name_label (session ref session_ref, SR ref sr, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR                                  |
|`string`                      |`value`                       |The name label for the SR               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given SR.

_Signature:_

```
void set_other_config (session ref session_ref, SR ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;physical&#95;size

_Overview:_

Sets the SR's physical&#95;size field

_Signature:_

```
void set_physical_size (session ref session_ref, SR ref self, int value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |The SR to modify                        |
|`int`                         |`value`                       |The new value of the SR's physical&#95;size|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;shared

_Overview:_

Sets the shared flag on the SR

_Signature:_

```
void set_shared (session ref session_ref, SR ref sr, bool value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR                                  |
|`bool`                        |`value`                       |True if the SR is shared                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;sm&#95;config

_Overview:_

Set the sm&#95;config field of the given SR.

_Signature:_

```
void set_sm_config (session ref session_ref, SR ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given SR.

_Signature:_

```
void set_tags (session ref session_ref, SR ref self, string set value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`self`                        |reference to the object                 |
|`string set`                  |`value`                       |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

### RPC name: update

_Overview:_

Refresh the fields on the SR object

_Signature:_

```
void update (session ref session_ref, SR ref sr)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`SR ref`                      |`sr`                          |The SR whose fields should be refreshed |

_Minimum Role:_ pool-operator

_Return Type:_ `void`
