# Class: VM&#95;metrics

The metrics associated with a VM

## Fields for class: VM&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`current_domain_type`|`domain_type`       |_RO/runtime_   |The current domain type of the VM &#40;for running,suspended, or paused VMs&#41;. The last&#45;known domain type for halted VMs.|
|`hvm`               |`bool`              |_RO/runtime_   |hardware virtual machine                |
|`install_time`      |`datetime`          |_RO/runtime_   |Time at which the VM was installed      |
|`last_updated`      |`datetime`          |_RO/runtime_   |Time at which this information was last updated|
|`memory_actual`     |`int`               |_RO/runtime_   |Guest's actual memory &#40;bytes&#41;   |
|`nested_virt`       |`bool`              |_RO/runtime_   |VM supports nested virtualisation       |
|`nomigrate`         |`bool`              |_RO/runtime_   |VM is immobile and can't migrate between hosts|
|`other_config`      |`(string -> string) map`|_RW_           |additional configuration                |
|`start_time`        |`datetime`          |_RO/runtime_   |Time at which this VM was last booted   |
|`state`             |`string set`        |_RO/runtime_   |The state of the guest, eg blocked, dying etc|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VCPUs_CPU`         |`(int -> int) map`  |_RO/runtime_   |VCPU to PCPU map                        |
|`VCPUs_flags`       |`(int -> string set) map`|_RO/runtime_   |CPU flags &#40;blocked,online,running&#41;|
|`VCPUs_number`      |`int`               |_RO/runtime_   |Current number of VCPUs                 |
|`VCPUs_params`      |`(string -> string) map`|_RO/runtime_   |The live equivalent to VM.VCPUs&#95;params|
|`VCPUs_utilisation` |`(int -> float) map`|_RO/runtime_   |**Removed.** Utilisation for all of guest's current VCPUs|

## RPCs associated with class: VM&#95;metrics

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VM&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_ref, VM_metrics ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VM&#95;metrics instances known to the system.

_Signature:_

```
VM_metrics ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VM_metrics ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VM&#95;metrics references to VM&#95;metrics records for all VM&#95;metrics instances known to the system.

_Signature:_

```
(VM_metrics ref -> VM_metrics record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VM_metrics ref -> VM_metrics record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VM&#95;metrics instance with the specified UUID.

_Signature:_

```
VM_metrics ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VM_metrics ref`

reference to the object

### RPC name: get&#95;current&#95;domain&#95;type

_Overview:_

Get the current&#95;domain&#95;type field of the given VM&#95;metrics.

_Signature:_

```
domain_type get_current_domain_type (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `domain_type`

value of the field

### RPC name: get&#95;hvm

_Overview:_

Get the hvm field of the given VM&#95;metrics.

_Signature:_

```
bool get_hvm (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;install&#95;time

_Overview:_

Get the install&#95;time field of the given VM&#95;metrics.

_Signature:_

```
datetime get_install_time (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given VM&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;memory&#95;actual

_Overview:_

Get the memory/actual field of the given VM&#95;metrics.

_Signature:_

```
int get_memory_actual (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;nested&#95;virt

_Overview:_

Get the nested&#95;virt field of the given VM&#95;metrics.

_Signature:_

```
bool get_nested_virt (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;nomigrate

_Overview:_

Get the nomigrate field of the given VM&#95;metrics.

_Signature:_

```
bool get_nomigrate (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VM&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VM&#95;metrics.

_Signature:_

```
VM_metrics record get_record (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_metrics record`

all fields from the object

### RPC name: get&#95;start&#95;time

_Overview:_

Get the start&#95;time field of the given VM&#95;metrics.

_Signature:_

```
datetime get_start_time (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

### RPC name: get&#95;state

_Overview:_

Get the state field of the given VM&#95;metrics.

_Signature:_

```
string set get_state (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VM&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VCPUs&#95;CPU

_Overview:_

Get the VCPUs/CPU field of the given VM&#95;metrics.

_Signature:_

```
(int -> int) map get_VCPUs_CPU (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(int -> int) map`

value of the field

### RPC name: get&#95;VCPUs&#95;flags

_Overview:_

Get the VCPUs/flags field of the given VM&#95;metrics.

_Signature:_

```
(int -> string set) map get_VCPUs_flags (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(int -> string set) map`

value of the field

### RPC name: get&#95;VCPUs&#95;number

_Overview:_

Get the VCPUs/number field of the given VM&#95;metrics.

_Signature:_

```
int get_VCPUs_number (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

### RPC name: get&#95;VCPUs&#95;params

_Overview:_

Get the VCPUs/params field of the given VM&#95;metrics.

_Signature:_

```
(string -> string) map get_VCPUs_params (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;VCPUs&#95;utilisation

**This message is removed.**

_Overview:_

Get the VCPUs/utilisation field of the given VM&#95;metrics.

_Signature:_

```
(int -> float) map get_VCPUs_utilisation (session ref session_ref, VM_metrics ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(int -> float) map`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VM&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, VM_metrics ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VM&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_ref, VM_metrics ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM_metrics ref`              |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`
